@@ -39,7 +39,7 @@ if not platform.system() == "Windows":
 logger = logging.getLogger(__name__)
 
 
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.1.19")
 def check_default_data_ui_file_white_list(app, reporter):
     """
@@ -134,7 +134,7 @@ def _is_text_with_password_(soup, compiled_regex):
     return False
 
 
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.1.19")
 def check_lookups_white_list(app, reporter):
     """Check that `lookups/` contains only approved file types (.csv,
@@ -187,7 +187,7 @@ def check_lookups_white_list(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "splunk_appinspect")
+@splunk_appinspect.tags("cloud", "splunk_appinspect", "private_app")
 @splunk_appinspect.cert_version(min="1.1.19")
 def check_metadata_white_list(app, reporter):
     """Check that the `metadata/` directory only contains .meta files."""
@@ -287,7 +287,7 @@ def check_static_directory_file_white_list(app, reporter):
 # -------------------
 # authorize.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.1.20")
 def check_authorize_conf_admin_all_objects_privileges(app, reporter):
     """Check that authorize.conf does not grant excessive administrative
@@ -337,7 +337,7 @@ def check_authorize_conf_admin_all_objects_privileges(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="2.0.2")
 def check_authorize_conf_for_tokens_auth(app, reporter):
     """Check that authorize.conf does not contain a `tokens_auth` stanza
@@ -527,7 +527,7 @@ def _is_python_script(file_path):
 # -------------------
 # distsearch.conf
 # -------------------
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_distsearch_conf_for_concerning_replicated_file_size(app, reporter):
     """Check if concerningReplicatedFileSize in distsearch.conf is larger
@@ -566,7 +566,7 @@ def check_distsearch_conf_for_concerning_replicated_file_size(app, reporter):
 # -------------------
 # indexes.conf
 # -------------------
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.1.20")
 def check_indexes_conf_only_uses_splunk_db_variable(app, reporter):
     """Check that indexes defined in `indexes.conf` use relative paths starting
@@ -616,7 +616,7 @@ def check_indexes_conf_only_uses_splunk_db_variable(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.1.20")
 def check_for_index_volume_usage(app, reporter):
     """Check that `indexes.conf` does not declare volumes."""
@@ -647,7 +647,7 @@ def check_for_index_volume_usage(app, reporter):
 # -------------------
 # inputs.conf
 # -------------------
-@splunk_appinspect.tags("cloud", "inputs_conf")
+@splunk_appinspect.tags("cloud", "inputs_conf", "private_app")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_for_inputs_fifo_usage(app, reporter):
     """Check the `[fifo]` stanza in `inputs.conf` is not pointing to a path
@@ -677,7 +677,7 @@ def check_for_inputs_fifo_usage(app, reporter):
         reporter.not_applicable("The default/inputs.conf does not exist.")
 
 
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.2.1")
 def check_inputs_conf_for_tcp(app, reporter):
     """Check that `default/inputs.conf` or `local/inputs.conf` does not contain a `tcp` stanza."""
@@ -699,7 +699,7 @@ def check_inputs_conf_for_tcp(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.2.1")
 def check_inputs_conf_for_splunk_tcp(app, reporter):
     """Check that `default/inputs.conf` or `local/inputs.conf` does not contain a `splunktcp`
@@ -725,7 +725,7 @@ def check_inputs_conf_for_splunk_tcp(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.2.1")
 def check_inputs_conf_for_fschange(app, reporter):
     """Check that `default/inputs.conf` or `local/inputs.conf` does not contain a `fschange`
@@ -749,7 +749,7 @@ def check_inputs_conf_for_fschange(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "inputs_conf")
+@splunk_appinspect.tags("cloud", "inputs_conf", "private_app")
 @splunk_appinspect.cert_version(min="1.2.1")
 def check_inputs_conf_for_http_global_usage(app, reporter):
     """Check that `default/inputs.conf` or `local/inputs.conf` does not contain a `[http]`
@@ -776,7 +776,7 @@ def check_inputs_conf_for_http_global_usage(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "inputs_conf")
+@splunk_appinspect.tags("cloud", "inputs_conf", "private_app")
 @splunk_appinspect.cert_version(min="2.2.0")
 def check_inputs_conf_for_http_local_stanza_usage(app, reporter):
     """Check that `default/inputs.conf` or `local/inputs.conf` contains accurate `[http://name]`
@@ -804,7 +804,7 @@ def check_inputs_conf_for_http_local_stanza_usage(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.2.1")
 def check_inputs_conf_for_splunktcptoken(app, reporter):
     """Check that `default/inputs.conf` or `local/inputs.conf` does not contain a `splunktcptoken`
@@ -829,7 +829,7 @@ def check_inputs_conf_for_splunktcptoken(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.1")
 def check_inputs_conf_for_batch(app, reporter):
     """Check that batch input accesses files in a permitted way.
@@ -876,7 +876,7 @@ def check_inputs_conf_for_batch(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "splunk_appinspect")
+@splunk_appinspect.tags("cloud", "splunk_appinspect", "private_app")
 @splunk_appinspect.cert_version(min="2.2.0")
 def check_inputs_conf_batch_has_required_attributes(app, reporter):
     """Check that batch input has required attributes.
@@ -905,7 +905,7 @@ def check_inputs_conf_batch_has_required_attributes(app, reporter):
                 reporter.fail(reporter_output, file_path, section.lineno)
 
 
-@splunk_appinspect.tags("cloud", "splunk_appinspect")
+@splunk_appinspect.tags("cloud", "splunk_appinspect", "private_app")
 @splunk_appinspect.cert_version(min="1.2.1")
 def check_inputs_conf_for_udp(app, reporter):
     """Check that inputs.conf does not have any UDP inputs."""
@@ -927,7 +927,7 @@ def check_inputs_conf_for_udp(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_inputs_conf_for_ssl(app, reporter):
     """Check that inputs.conf does not have any SSL inputs."""
@@ -949,7 +949,7 @@ def check_inputs_conf_for_ssl(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="2.0.2")
 def check_inputs_conf_for_remote_queue_monitor(app, reporter):
     """Check that inputs.conf does not have any remote_queue inputs."""
@@ -1036,7 +1036,7 @@ def check_scripted_inputs_cmd_path_pattern(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="2.1.0")
 def check_scripted_inputs_python_version(app, reporter):
     """Check that python version is python3 for scripted inputs defined in inputs.conf.
@@ -1068,7 +1068,7 @@ def check_scripted_inputs_python_version(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_modular_inputs_scripts_exist_for_cloud(app, reporter):
     """Check that there is a script file in `bin/` for each modular input
@@ -1117,7 +1117,7 @@ def check_modular_inputs_scripts_exist_for_cloud(app, reporter):
 # -------------------
 # setup.xml
 # -------------------
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="2.1.0")
 def check_setup_xml_in_default(app, reporter):
     """Check that `setup.xml` does not exist in the app default folder
@@ -1127,7 +1127,7 @@ def check_setup_xml_in_default(app, reporter):
             "Do not use `default/setup.xml` in the Cloud environment "
             "since it behaves incorrectly on distributed Splunk Cloud deployments. "
             "Consider leveraging HTML and JS and using setup view instead. "
-            "For example: https://github.com/splunk/Developer_Guidance_Setup_View_Example"
+            "For example: https://dev.splunk.com/enterprise/docs/developapps/manageknowledge/setuppage/"
         )
         reporter.fail(reporter_output)
 
@@ -1241,7 +1241,7 @@ def check_transforms_conf_for_external_cmd(app, reporter, target_splunk_version)
 # -------------------
 # audit.conf
 # -------------------
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_audit_conf_black_list(app, reporter):
     """Check that app does not contain audit.conf, as it is prohibited in
@@ -1261,7 +1261,7 @@ def check_audit_conf_black_list(app, reporter):
 # -------------------
 # authentication.conf
 # -------------------
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="2.0.0")
 def check_stanza_of_authentication_conf(app, reporter):
     """Check that only role-mapping stanza is allowed in authenticaiton.conf as long as it doesn't map users to a cloud-internal role."""
@@ -1319,7 +1319,7 @@ def check_stanza_of_authentication_conf(app, reporter):
 # -------------------
 # bookmarks.conf
 # -------------------
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="2.0.2")
 def check_bookmarks_conf_black_list(app, reporter):
     """Check that app does not contain bookmarks.conf as this
@@ -1336,7 +1336,7 @@ def check_bookmarks_conf_black_list(app, reporter):
 # -------------------
 # crawl.conf
 # -------------------
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_introspection_of_cloud_filesystem(app, reporter):
     """Check that app does not contain crawl.conf
@@ -1357,7 +1357,7 @@ def check_introspection_of_cloud_filesystem(app, reporter):
 # -------------------
 # datatypesbnf.conf
 # -------------------
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_datatypesbnf_conf_black_list(app, reporter):
     """Check that app does not contain datatypesbnf.conf, as it is prohibited
@@ -1375,7 +1375,7 @@ def check_datatypesbnf_conf_black_list(app, reporter):
 # -------------------
 # default-mode.conf
 # -------------------
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_default_mode_conf_black_list(app, reporter):
     """Check that app does not contain default-mode.conf is as it is
@@ -1395,7 +1395,9 @@ def check_default_mode_conf_black_list(app, reporter):
 # -------------------
 # deployment.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "splunk_5_0", "removed_feature", "cloud")
+@splunk_appinspect.tags(
+    "splunk_appinspect", "splunk_5_0", "removed_feature", "cloud", "private_app"
+)
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_deployment_conf_black_list(app, reporter):
     """Check that app does not contain deployment.conf. Apps should leave
@@ -1420,7 +1422,7 @@ def check_deployment_conf_black_list(app, reporter):
 # -------------------
 # deploymentclient.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_deploymentclient_conf_black_list(app, reporter):
     """Check that app does not contain deploymentclient.conf as it configures
@@ -1439,7 +1441,7 @@ def check_deploymentclient_conf_black_list(app, reporter):
 # -------------------
 # health.conf
 # -------------------
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="2.0.2")
 def check_health_conf_black_list(app, reporter):
     """Check that app does not contain health.conf as sc_admin is not able
@@ -1457,7 +1459,7 @@ def check_health_conf_black_list(app, reporter):
 # -------------------
 # instance.cfg.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_instance_cfg_conf_black_list(app, reporter):
     """Check that app does not contain instance.cfg.conf. Apps should not
@@ -1476,7 +1478,7 @@ def check_instance_cfg_conf_black_list(app, reporter):
 # -------------------
 # literals.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_literals_conf_black_list(app, reporter):
     """Check that app does not contain literals.conf. Apps should not
@@ -1495,7 +1497,7 @@ def check_literals_conf_black_list(app, reporter):
 # -------------------
 # messages.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_messages_conf_black_list(app, reporter):
     """Check that app does not contain messages.conf. Apps should not
@@ -1514,7 +1516,7 @@ def check_messages_conf_black_list(app, reporter):
 # -------------------
 # passwords.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_that_passwords_conf_not_exist(app, reporter):
     """Check that the app does not have default/passwords.conf, otherwise, warn it.
@@ -1531,7 +1533,7 @@ def check_that_passwords_conf_not_exist(app, reporter):
 # -------------------
 # props.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_that_no_configurations_of_default_source_type_in_props_conf(app, reporter):
     """Check that the app does not contain configurations of default source type in props.conf,
@@ -1569,7 +1571,7 @@ def check_that_no_configurations_of_default_source_type_in_props_conf(app, repor
 # -------------------
 # pubsub.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_pubsub_conf_black_list(app, reporter):
     """Check that app does not contain pubsub.conf as it defines a custom
@@ -1588,7 +1590,7 @@ def check_pubsub_conf_black_list(app, reporter):
 # -------------------
 # segmenters.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_segmenters_conf_black_list(app, reporter):
     """Check that app does not contain segmenters.conf with splunk stanza. A misconfigured
@@ -1632,7 +1634,7 @@ def check_segmenters_conf_black_list(app, reporter):
 # -------------------
 # serverclass.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_serverclass_conf_black_list(app, reporter):
     """Check that app does not contain serverclass.conf as it defines
@@ -1651,7 +1653,7 @@ def check_serverclass_conf_black_list(app, reporter):
 # -------------------
 # serverclass.seed.xml.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_serverclass_seed_xml_conf_black_list(app, reporter):
     """Check that app does not contain serverclass.seed.xml.conf as it
@@ -1672,7 +1674,7 @@ def check_serverclass_seed_xml_conf_black_list(app, reporter):
 # -------------------
 # source-classifier.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_source_classifier_conf_black_list(app, reporter):
     """Check that app does not contain source-classifier.conf.conf as it
@@ -1691,7 +1693,7 @@ def check_source_classifier_conf_black_list(app, reporter):
 # -------------------
 # sourcetypes.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_sourcetypes_conf_black_list(app, reporter):
     """Check that app does not contain sourcetypes.conf as it is a
@@ -1710,7 +1712,7 @@ def check_sourcetypes_conf_black_list(app, reporter):
 # -------------------
 # splunk-launch.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_splunk_launch_conf_black_list(app, reporter):
     """Check that app does not contain splunk-launch.conf as it defines
@@ -1729,7 +1731,7 @@ def check_splunk_launch_conf_black_list(app, reporter):
 # -------------------
 # telemetry.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "telemetry")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "telemetry", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_telemetry_conf_black_list(app, reporter):
     """Check that app does not contain telemetry.conf as it controls a
@@ -1752,7 +1754,7 @@ def check_telemetry_conf_black_list(app, reporter):
 # -------------------
 # user-seed.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_user_seed_conf_black_list(app, reporter):
     """Check that app does not contain user-seed.conf as it is used to
@@ -1770,7 +1772,7 @@ def check_user_seed_conf_black_list(app, reporter):
 # -------------------
 # wmi.conf
 # -------------------
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_wmi_conf_black_list(app, reporter):
     """Check that app does not contain wmi.conf is as it is prohibited in
@@ -1790,7 +1792,7 @@ def check_wmi_conf_black_list(app, reporter):
 # -------------------
 # workload_pools.conf
 # -------------------
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="2.0.2")
 def check_workload_pools_conf_black_list(app, reporter):
     """Check that app does not contain workload_pools.conf in Cloud. App should
@@ -1809,7 +1811,7 @@ def check_workload_pools_conf_black_list(app, reporter):
 # -------------------
 # workload_rules.conf
 # -------------------
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="2.0.2")
 def check_workload_rules_conf_black_list(app, reporter):
     """Check that app does not contain workload_rules.conf in Cloud as it
@@ -2116,7 +2118,7 @@ def check_for_java(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud")
+@splunk_appinspect.tags("cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_for_implementing_tscollect(app, reporter):
     """Check that use of
