@@ -65,6 +65,11 @@ def check_capture_groups_in_transforms(app, reporter):
             if section.has_option("REGEX") and section.has_option("FORMAT"):
                 regex = section.get_option("REGEX")
                 fmt = section.get_option("FORMAT")
+
+                if fmt.value and (not re.search('\$[\d]+', fmt.value)):
+                    # Do not continue to check if there is no $\d in FORMAT.
+                    continue
+
                 try:
                     # Splunk regular expressions are PCRE (Perl Compatible Regular Expressions)
                     # re does not support PCRE, so use regex as re, see import part
@@ -79,8 +84,8 @@ def check_capture_groups_in_transforms(app, reporter):
                     ).format(section.name, regex.value, file_path, regex.lineno)
                     reporter.fail(reporter_output, file_path, regex.lineno)
                     return
-                unused_groups = []
 
+                unused_groups = []
                 for i in range(pattern.groups):
                     if fmt.value.find("$" + str(i + 1)) < 0:
                         unused_groups.append("$" + str(i + 1))
