@@ -1,4 +1,8 @@
-# Copyright 2018 Splunk Inc. All rights reserved.
+# Copyright 2019 Splunk Inc. All rights reserved.
+
+"""
+Helper module for documentation links generation
+"""
 
 # Python Standard Libraries
 # Third-Party Libraries
@@ -16,6 +20,8 @@ class DocumentationLinks(object):
         """Returns the Splunk Doc link for a conf file."""
         if conf_file in LATEST_CONFS:
             uri_path = conf_file.replace(".", "")
-            return "https://docs.splunk.com/Documentation/Splunk/latest/Admin/{}".format(uri_path)
-        else:
-            return "Unable to find doc link for {}".format(conf_file)
+            return "https://docs.splunk.com/Documentation/Splunk/latest/Admin/{}".format(
+                uri_path
+            )
+
+        return "Unable to find doc link for {}".format(conf_file)
