@@ -1,5 +1,5 @@
 """ A collection of Splunk defined conf files"""
-# it contains all conf specs in 6.0~8.0 from https://docs.splunk.com/Documentation/Splunk/{6.0-8.0}/Admin/Appconf
+# it contains all conf specs in 6.0~8.1.3 from https://docs.splunk.com/Documentation/Splunk/{6.0-8.1.3}/Admin/Appconf
 
 SPLUNK_DEFINED_CONFS = {
     "alert_actions.conf",
@@ -24,6 +24,7 @@ SPLUNK_DEFINED_CONFS = {
     "eventtypes.conf",
     "federated.conf",
     "fields.conf",
+    "global-banner.conf",
     "health.conf",
     "indexes.conf",
     "inputs.conf",
@@ -67,12 +68,13 @@ SPLUNK_DEFINED_CONFS = {
     "web.conf",
     "wmi.conf",
     "workflow_actions.conf",
+    "workload_policy.conf",
     "workload_pools.conf",
     "workload_rules.conf",
 }
 
-# the conf files for latest version of splunk (8.0 currently)
-# take from https://docs.splunk.com/Documentation/Splunk/8.0.0/Admin/Alertactionsconf
+# the conf files for latest version of splunk (8.1.3 currently)
+# take from https://docs.splunk.com/Documentation/Splunk/latest/Admin/Alertactionsconf
 LATEST_CONFS = {
     "alert_actions.conf",
     "app.conf",
@@ -94,6 +96,7 @@ LATEST_CONFS = {
     "event_renderers.conf",
     "eventtypes.conf",
     "federated.conf",
+    "global-banner.conf",
     "fields.conf",
     "health.conf",
     "indexes.conf",
@@ -136,6 +139,7 @@ LATEST_CONFS = {
     "web.conf",
     "wmi.conf",
     "workflow_actions.conf",
+    "workload_policy.conf",
     "workload_pools.conf",
     "workload_rules.conf",
 }
